@@ -805,15 +805,35 @@ def list_queries(
 
 @cli.command()
 @config_validation_options
+@click.option(
+    "--skip-dw",
+    is_flag=True,
+    default=False,
+    help="If specified, skips the data warehouse validations",
+)
 @pass_config
 @exception_handler
-def validate_configs(config: CLIContext, config_dir: str) -> None:
+def validate_configs(config: CLIContext, config_dir: str, skip_dw: bool = False) -> None:
     """Validate yaml configs found in specified config directory"""
-
-    spinner = Halo(text=f"Validating configs in '{config_dir}'...", spinner="dots")
+    spinner = Halo(text=f"Running parsing and semantic validations for configs in '{config_dir}'...", spinner="dots")
     spinner.start()
-    repo, branch, commit = config.mql.validate_configs(config_dir)
-    spinner.succeed(f"🎉 Successfully validated configs for commit ({commit}) in repo ({repo}), on branch ({branch})")
+
+    # Currently if this fails, an exception is thrown, and the calling function handles it with a decorator
+    model = config.mql.validate_configs(config_dir=config_dir)
+    spinner.succeed(
+        f"🦄 Successfully validated parsing and semantics of configs for commit ({model.commit}) in repo ({model.repository}), on branch ({model.branch})"
+    )
+
+    if not skip_dw:
+        spinner_dw = Halo(text=f"Running data warehouse validations for configs in '{config_dir}'...", spinner="dots")
+        spinner_dw.start()
+        issues = config.mql.validate_model_against_data_warehouse(model.id)
+        if issues is not None and len(issues) == 0:
+            spinner_dw.succeed(f"🎉 Successfully validated model {model.id} against data warehouse, no issues found")
+        else:
+            spinner_dw.fail(f"😬 Issues found when validating model {model.id} against data warehouse")
+            print(colored("\n".join(issues), "red"))
+            return None
 
 
 @cli.command()
@@ -821,39 +841,47 @@ def validate_configs(config: CLIContext, config_dir: str) -> None:
 @click.option("--pin", type=bool, required=False, help="Whether to pin the model or not")
 @click.option("--force-primary", is_flag=True, default=None, help="Make this model current")
 @click.option(
-    "--dw-validations",
+    "--skip-dw",
     is_flag=True,
     default=False,
-    help="Run data warehouse validations after model is successfully committed",
+    help="If specified, skips the data warehouse validations",
 )
 @pass_config
 @click.pass_context
-@exception_handler
 def commit_configs(
     ctx: click.core.Context,
     config: CLIContext,
     config_dir: str,
     pin: Optional[bool] = None,
     force_primary: Optional[bool] = None,
-    dw_validations: Optional[bool] = False,
+    skip_dw: bool = False,
 ) -> None:
     """Commit yaml configs found in specified config directory"""
-    spinner = Halo(text="Parsing and uploading configs…", spinner="dots")
+    spinner = Halo(text=f"Running parsing and semantic validations for configs in '{config_dir}'...", spinner="dots")
     spinner.start()
-    model = config.mql.commit_configs(config_dir, force_primary)
+
+    # Currently if this fails, an exception is thrown, and the calling function handles it with a decorator
+    model = config.mql.commit_configs(config_dir=config_dir)
     spinner.succeed(
-        f"🦄 Successfully committed configs id {model.id} on branch {model.branch} with commit {model.commit}"
+        f"🦄 Successfully validated parsing and semantics of configs for commit ({model.commit}) in repo ({model.repository}), on branch ({model.branch})"
     )
 
-    if dw_validations:
-        spinner_dw = Halo(text="Validating commited model against data warehouse", spinner="dots")
+    if not skip_dw:
+        spinner_dw = Halo(text=f"Running data warehouse validations for configs in '{config_dir}'...", spinner="dots")
         spinner_dw.start()
         issues = config.mql.validate_model_against_data_warehouse(model.id)
         if issues is not None and len(issues) == 0:
-            spinner_dw.succeed(f"🚀 Successfully validated model {model.id} against data warehouse, no issues found")
+            spinner_dw.succeed(f"🎉 Successfully validated model {model.id} against data warehouse, no issues found")
         else:
-            spinner_dw.fail(f"❌ Issues found when validating model {model.id} against data warehouse")
+            spinner_dw.fail(f"😬 Issues found when validating model {model.id} against data warehouse")
             print(colored("\n".join(issues), "red"))
+            return None
+
+    if force_primary:
+        promote_spinner = Halo(text="Promoting commited model to be primary", spinner="dots")
+        promote_spinner.start()
+        config.mql.promote_model(model)
+        promote_spinner.succeed(f"🚀 Success! Model {model.id} is now the primary model for you org")
 
     if pin is None:
         if click.confirm("📌 Would you like to pin this model commit for future MQL queries?"):
