@@ -11,7 +11,12 @@ from typing import List, Dict, Optional, Tuple, Any
 from gql import Client, gql  # type: ignore
 from gql.transport.requests import RequestsHTTPTransport  # type: ignore
 
-from transform_tools.validate import upload_configs, ERROR_RESPONSE_PREFIX
+from transform_tools.validate import (
+    validate_configs as tt_validate_configs,
+    commit_configs as tt_commit_configs,
+    promote_model,
+    ERROR_RESPONSE_PREFIX,
+)
 from .constants import DEFAULT_QUERY_TIMEOUT, MAX_PAGE_SIZE
 from .exceptions import QueryRuntimeException
 from .utils import resolve_local_commit_info
@@ -112,20 +117,19 @@ class BackendInterface(BaseInterface):  # noqa: D
     ) -> None:
         super(BackendInterface, self).__init__(auth_header, rest_api_url, verify)
 
-    def _get_and_upload_configs(
-        self, mode: str, config_dir: str, repo: str, branch: str, commit: str, is_current: Optional[bool] = None
-    ) -> requests.Response:  # noqa: D
+    def validate_configs(self, config_dir: str) -> ModelKey:
+        """Finds and validates yaml configs in the provided directory"""
+        repo, branch, commit = resolve_local_commit_info(config_dir)
         try:
-            return upload_configs(
-                mode=mode,
+            model = tt_validate_configs(
                 auth_header=self.auth_header,
                 repo=repo,
                 branch=branch,
                 commit=commit,
                 config_dir=config_dir,
-                is_current=is_current,
                 api_url=self.rest_api_url,
             )
+            return model
         except Exception as e:
             error_content = str(e).split(ERROR_RESPONSE_PREFIX)
             error_msg = str(e)
@@ -134,19 +138,37 @@ class BackendInterface(BaseInterface):  # noqa: D
                 error_msg = f"🙈 {error_response['error_type']}: {error_response['message']}"
             raise Exception(error_msg) from None
 
-    def validate_configs(self, config_dir: str) -> Tuple[str, str, str]:  # noqa: D
-        """Finds and validates yaml configs in the provided directory"""
+    def commit_configs(self, config_dir: str, is_validation: bool = False) -> ModelKey:
+        """Finds, validates, and commits yaml configs in the provided directory"""
         repo, branch, commit = resolve_local_commit_info(config_dir)
-        self._get_and_upload_configs("validate", config_dir, repo, branch, commit)
+        try:
+            response = tt_commit_configs(
+                auth_header=self.auth_header,
+                repo=repo,
+                branch=branch,
+                commit=commit,
+                config_dir=config_dir,
+                is_validation=is_validation,
+                api_url=self.rest_api_url,
+            )
+            return ModelKey.from_snake_dict(response.json()["model"])
+        except Exception as e:
+            error_content = str(e).split(ERROR_RESPONSE_PREFIX)
+            error_msg = str(e)
+            if len(error_content) == 2:
+                error_response = json.loads(error_content[1])["error"]
+                error_msg = f"🙈 {error_response['error_type']}: {error_response['message']}"
+            raise Exception(error_msg) from None
 
-        return repo, branch, commit
-
-    def commit_configs(self, config_dir: str, is_current: Optional[bool] = None) -> ModelKey:
-        """Finds and validates yaml configs in the provided directory"""
-        repo, branch, commit = resolve_local_commit_info(config_dir)
-        r = self._get_and_upload_configs("commit", config_dir, repo, branch, commit, is_current)
-
-        return ModelKey.from_snake_dict(r.json()["model"])
+    def promote_model_with_key(self, model_key: ModelKey) -> None:
+        """Promotes a given model key to be the current/primary model for the organization"""
+        promote_model(
+            auth_header=self.auth_header,
+            repo=model_key.repository,
+            branch=model_key.branch,
+            commit=model_key.commit,
+            api_url=self.rest_api_url,
+        )
 
     def get_my_org(self) -> Organization:  # noqa: D
         """Queries for "my org" (the current user's org)"""
@@ -227,6 +249,27 @@ class BackendInterface(BaseInterface):  # noqa: D
             self.execute(query, variable_values={"modelId": model_id})["myOrganization"]["models"][0]
         )
 
+    def get_current_model_key(self) -> "ModelKey":
+        """Queries for the user's org's current model key"""
+        query = gql(
+            """
+            query CurrentModelKeyQuery {
+                myOrganization {
+                    currentModel {
+                        id
+                        organizationId
+                        gitBranch
+                        gitCommit
+                        gitRepo
+                        createdAt
+                        isCurrent
+                    }
+                }
+            }
+            """
+        )
+        return ModelKey.from_gql_dict(self.execute(query)["myOrganization"]["currentModel"][0])
+
     def get_org_mql_servers(self) -> List[MQLServer]:  # noqa: D
         query = gql(
             """
