@@ -186,14 +186,18 @@ class MQLClient:
         model_key = self.get_model_key(model_key_id) if model_key_id else None
         return sorted(self.context.mql_client.get_materializations(model_key), key=lambda m: m.name)
 
-    def commit_configs(self, config_dir: str, is_current: Optional[bool] = None) -> ModelKey:
+    def commit_configs(self, config_dir: str, is_validation: bool = False) -> ModelKey:
         """Validates and commits yaml transform configs in the provided directory. Returns a ModelKey object."""
-        return self.context.backend_client.commit_configs(config_dir, is_current)
+        return self.context.backend_client.commit_configs(config_dir=config_dir, is_validation=is_validation)
 
-    def validate_configs(self, config_dir: str) -> Tuple[str, str, str]:
+    def validate_configs(self, config_dir: str) -> ModelKey:
         """Finds and validates yaml transform configs in the provided directory. Returns a tuple (repo, branch, commit)"""
         return self.context.backend_client.validate_configs(config_dir)
 
+    def promote_model(self, model_key: ModelKey) -> None:
+        """Promotes a given model key to be the current/primary model for the organization"""
+        return self.context.backend_client.promote_model_with_key(model_key=model_key)
+
     def health_report(self) -> List[ServerHealthReport]:
         """Performs a health check on all mql servers within the organization and returns List[ServerHealthReport]."""
         servers = self.context.backend_client.get_org_mql_servers()
@@ -261,6 +265,10 @@ class MQLClient:
         """Retrieves ModelKey object given the id."""
         return self.context.backend_client.get_model_key(model_key_id)
 
+    def get_current_model_key(self) -> ModelKey:
+        """Retrieves the current ModelKey object for the user's organization"""
+        return self.context.backend_client.get_current_model_key()
+
     def latest_mql_image(self) -> MQLServerImage:
         """Retrieves the latest MQL server image."""
         return self.context.backend_client.get_latest_mql_server_image()
